@@ -302,7 +302,6 @@ class Anaml:
             fields updated.
         """
         r = self._put(f"/feature/{str(feature.id.value)}", json=feature.to_json())
-        # TODO: Is this, in fact, an int?
         _ = self._int_or_handle_errors(r)
         return self.get_feature_by_id(int(feature.id.value))
 
@@ -711,8 +710,9 @@ class Anaml:
             The check object, with unique identifier and other computed fields updated.
         """
         r = self._put("/checks/" + str(check.commit.value) + "/" + str(check.id.value), json=check.to_json())
-        result = self._json_or_handle_errors(r)
-        return Check.from_json(result)
+        _ = self._json_or_handle_errors(r)
+        # Let's re-load the saved check. Just to make sure it's all up to date.
+        return self.get_check(check.commit, check.id)
 
     #####################
     # Load feature data #
